@@ -16,7 +16,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \qmltype PositionSource
-    //! \instantiates QDeclarativePositionSource
+    //! \nativetype QDeclarativePositionSource
     \inqmlmodule QtPositioning
     \since 5.2
 
@@ -69,10 +69,6 @@ QT_BEGIN_NAMESPACE
     }
     \endcode
 
-    The \l{geoflickr}{GeoFlickr} example application shows how to use
-    a PositionSource in your application to retrieve local data for users
-    from a REST web service.
-
     \section2 Controlling Operation State
 
     As it's mentioned above, PositionSource provides two ways to control its
@@ -151,6 +147,8 @@ QT_BEGIN_NAMESPACE
 */
 
 QDeclarativePositionSource::QDeclarativePositionSource()
+    : m_singleUpdate(0), m_regularUpdates(0), m_componentComplete(0),
+      m_parametersInitialized(0), m_startRequested(0), m_defaultSourceUsed(0)
 {
     m_position.setValueBypassingBindings(new QDeclarativePosition(this));
 }
@@ -191,7 +189,7 @@ void QDeclarativePositionSource::setName(const QString &newName)
     if (newName.isEmpty() && m_defaultSourceUsed)
         return; // previously attached to a default source, now requesting the same.
 
-    const QString previousName = name();
+    const QString previousName = m_sourceName.valueBypassingBindings();
 
     if (!m_componentComplete || !m_parametersInitialized) {
         if (previousName != newName) {
@@ -786,7 +784,8 @@ void QDeclarativePositionSource::componentComplete()
         if (!p->isInitialized()) {
             m_parametersInitialized = false;
             connect(p, &QDeclarativePluginParameter::initialized,
-                    this, &QDeclarativePositionSource::onParameterInitialized);
+                    this, &QDeclarativePositionSource::onParameterInitialized,
+                    Qt::SingleShotConnection);
         }
     }
 
